<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Magpaper Pro
 * @since Magpaper Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function magpaper_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magpaper-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function magpaper_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'magpaper-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'magpaper_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function magpaper_pro_typography_options(){
        // return $output;
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'magpaper-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/uploads/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '-', array_map( 'strtolower', $family_str_arr ) );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return apply_filters( 'magpaper_pro_font_choices', $font_family_arr );
    }
endif;

if ( ! function_exists( 'magpaper_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function magpaper_pro_site_layout() {
        $magpaper_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'magpaper_pro_site_layout', $magpaper_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'magpaper_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function magpaper_pro_selected_sidebar() {
        $magpaper_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'magpaper-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'magpaper-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'magpaper-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'magpaper-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'magpaper-pro' ),
        );

        $output = apply_filters( 'magpaper_pro_selected_sidebar', $magpaper_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'magpaper_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function magpaper_pro_sidebar_position() {
        $magpaper_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'magpaper_pro_sidebar_position', $magpaper_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'magpaper_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function magpaper_pro_pagination_options() {
        $magpaper_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'magpaper-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'magpaper-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'magpaper-pro' ),
        );

        $output = apply_filters( 'magpaper_pro_pagination_options', $magpaper_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'magpaper_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function magpaper_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'magpaper-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'magpaper-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'magpaper-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'magpaper-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'magpaper-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'magpaper-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'magpaper-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'magpaper-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'magpaper-pro' ),
        );
        return apply_filters( 'magpaper_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'magpaper_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magpaper_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'magpaper-pro' ),
            'off'       => esc_html__( 'Disable', 'magpaper-pro' )
        );
        return apply_filters( 'magpaper_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'magpaper_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function magpaper_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'magpaper-pro' ),
            'off'       => esc_html__( 'No', 'magpaper-pro' )
        );
        return apply_filters( 'magpaper_pro_hide_options', $arr );
    }
endif;

